"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Point = void 0;
var vector_1 = require("./vector");
var util_1 = require("./util");
/** Create point using coordinates */
function Point() {
    var coordinates = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        coordinates[_i] = arguments[_i];
    }
    if (process.env.NODE_ENV !== 'production') {
        if (!coordinates ||
            !Array.isArray(coordinates) ||
            !coordinates.every(function (x) { return typeof x === 'number'; }))
            throw TypeError("Invalid Point is being created: " + JSON.stringify(coordinates));
    }
    return {
        magnitude: coordinates.length,
        coordinates: coordinates,
        to: function (p2) {
            util_1.checkCoordinates(this, p2);
            return vector_1.Vec.apply(void 0, p2.coordinates.map(function (n, i) { return n - coordinates[i]; }));
        },
        mid: function (p2) {
            util_1.checkCoordinates(this, p2);
            return this.apply(this.to(p2).mul(1 / 2));
        },
        apply: function (vec) {
            util_1.checkCoordinates(this, vec);
            return Point.apply(void 0, coordinates.map(function (n, i) { return n + vec.coordinates[i]; }));
        },
        equal: function (p2) {
            util_1.checkCoordinates(this, p2);
            return coordinates.every(function (n, i) { return n === p2.coordinates[i]; });
        },
        toString: function (name) {
            return name + "(" + coordinates.map(function (x) { return x.toString(); }).join(', ') + ")";
        },
    };
}
exports.Point = Point;
//# sourceMappingURL=point.js.map