import { Latexable, Angle } from './util';
/** Structure representing N-dimensional vector */
export interface Vector extends Latexable {
    /** Length of vector. */
    length: number;
    /** Magnitude of vector. */
    magnitude: number;
    /** Coordinates of vector. */
    coordinates: readonly number[];
    /** Add two vectors. Returns new vector. */
    add(b: Vector): Vector;
    /** Subtract two vectors. Returns new vector. */
    sub(b: Vector): Vector;
    /** Multiply vector by scalar. Returns new vector. */
    mul(b: number): Vector;
    /** Find dot product of two vectors. */
    dot(b: Vector): number;
    /** Find angle between two vectors. */
    angle(b: Vector): ReturnType<typeof Angle>;
    /** Create new vector with opposite direction with same length. */
    neg(): Vector;
    /** Check if two vectors are equal. */
    equal(v2: Vector): boolean;
}
export declare function Vec(...coordinates: number[]): Vector;
