"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Vec = void 0;
var util_1 = require("./util");
function Vec() {
    var coordinates = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        coordinates[_i] = arguments[_i];
    }
    if (process.env.NODE_ENV !== 'production') {
        if (!coordinates ||
            !Array.isArray(coordinates) ||
            !coordinates.every(function (x) { return typeof x === 'number'; }))
            throw Error("Invalid Vec is being created: " + JSON.stringify(coordinates));
    }
    return {
        length: Math.sqrt(coordinates.reduce(function (acc, curr) { return acc + Math.pow(curr, 2); }, 0)),
        magnitude: coordinates.length,
        coordinates: coordinates,
        add: function (b) {
            util_1.checkCoordinates(this, b);
            return Vec.apply(void 0, coordinates.map(function (n, i) { return n + b.coordinates[i]; }));
        },
        sub: function (b) {
            util_1.checkCoordinates(this, b);
            return Vec.apply(void 0, coordinates.map(function (n, i) { return n - b.coordinates[i]; }));
        },
        mul: function (b) {
            return Vec.apply(void 0, coordinates.map(function (x) { return x * b; }));
        },
        neg: function () {
            return Vec.apply(void 0, coordinates.map(function (x) { return -x; }));
        },
        dot: function (b) {
            util_1.checkCoordinates(this, b);
            return coordinates.reduce(function (acc, curr, i) { return acc + curr * b.coordinates[i]; }, 0);
        },
        angle: function (b) {
            util_1.checkCoordinates(this, b);
            return util_1.Angle(Math.acos(this.dot(b) / (this.length * b.length)));
        },
        equal: function (v2) {
            util_1.checkCoordinates(this, v2);
            return coordinates.every(function (n, i) { return n === v2.coordinates[i]; });
        },
        toString: function (name) {
            return "\\vec{" + name + "} = (" + coordinates
                .map(function (x) { return x.toString(); })
                .join(', ') + ")";
        },
    };
}
exports.Vec = Vec;
//# sourceMappingURL=vector.js.map